==> iTop-3.2.0-2-14758.zip: web/dictionaries/ui/pages/preferences/fr.dictionary.itop.preferences.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('FR FR', 'French', 'Français', [
	'UI:Favorites:General:ShowSummaryCards' => 'Afficher un aperçu sur les liens',
	'UI:Favorites:General:ShowSummaryCards+' => 'Quand la souris passe sur un lien vers un objet, une vue synthètique est affichée si elle existe pour cette classe d\'objets',
	'UI:Preferences:ActivityPanel:EntryFormOpened' => 'Formulaire de saisie ouvert par défaut',
	'UI:Preferences:ActivityPanel:EntryFormOpened+' => 'État du formulaire de saisie lors de l\'affichage d\'un objet. Si la case est décochée, le formulaire pourra être ouvert en utilisant l\'icone "Nouvelle entrée".',
	'UI:Preferences:ActivityPanel:Title' => 'Panneau d\'activité',
	'UI:Preferences:ChooseAPlaceholder' => 'Avatar de l\'utilisateur',
	'UI:Preferences:ChooseAPlaceholder+' => 'Choisissez un avatar qui sera affiché si le contact associé à votre compte utilisateur n\'en possède pas',
	'UI:Preferences:ChooseAPlaceholder:Success:Message' => 'Votre avatar a été mis à jour avec succès',
	'UI:Preferences:General:Theme' => 'Thème',
	'UI:Preferences:General:Theme:DefaultThemeLabel' => '%1$s (défaut)',
	'UI:Preferences:General:Title' => 'Général',
	'UI:Preferences:General:Toasts' => 'Position des notifications toast',
	'UI:Preferences:General:Toasts:Bottom' => 'En bas',
	'UI:Preferences:General:Toasts:Top' => 'En haut',
	'UI:Preferences:Lists:Title' => 'Listes',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset' => 'Réinitialiser',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset:Tooltip' => 'Remettre les raccourcis claviers par défaut',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Tooltip' => 'Enregistrer un raccourci clavier',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Input:Hint' => 'Saisissez un raccourci clavier',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Title' => 'Raccourcis clavier de l\'application',
	'UI:Preferences:RichText:Title' => 'Éditeur texte riche',
	'UI:Preferences:RichText:ToolbarState' => 'Affichage par défaut de la barre d\'outil',
	'UI:Preferences:RichText:ToolbarState:Collapsed' => 'Replié',
	'UI:Preferences:RichText:ToolbarState:Expanded' => 'Déplié',
	'UI:Preferences:Tabs:Layout:Horizontal' => 'Horizontal',
	'UI:Preferences:Tabs:Layout:Label' => 'Affichage',
	'UI:Preferences:Tabs:Layout:Vertical' => 'Vertical',
	'UI:Preferences:Tabs:Scrollable:Classic' => 'Classique',
	'UI:Preferences:Tabs:Scrollable:Label' => 'Navigation',
	'UI:Preferences:Tabs:Scrollable:Scrollable' => 'Défilement',
	'UI:Preferences:Tabs:Title' => 'Onglets',
	'UI:Preferences:Title' => 'Préférences',
	'UI:Preferences:UserInterface:Title' => 'Interface utilisateur',
	'UI:Preferences:Notifications' => 'Notifications',
	'UI:Preferences:Notifications+' => 'Désabonnez-vous des notifications qui vous importunent (emails et news) en suivant <a href="%1$s">ce lien</a>.',
]);

==> iTop-3.2.2-1-17851.zip: web/dictionaries/ui/pages/preferences/fr.dictionary.itop.preferences.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('FR FR', 'French', 'Français', array(
	'UI:Preferences:Title' => 'Préférences',
	'UI:Preferences:UserInterface:Title' => 'Interface utilisateur',
	'UI:Preferences:General:Title' => 'Général',
	'UI:Preferences:General:Theme' => 'Thème',
	'UI:Preferences:General:Theme:DefaultThemeLabel' => '%1$s (défaut)',
	'UI:Favorites:General:ShowSummaryCards' => 'Afficher un aperçu sur les liens',
	'UI:Favorites:General:ShowSummaryCards+' => 'Quand la souris passe sur un lien vers un objet, une vue synthètique est affichée si elle existe pour cette classe d\'objets',
	'UI:Preferences:Lists:Title' => 'Listes',
	'UI:Preferences:RichText:Title' => 'Éditeur texte riche',
	'UI:Preferences:RichText:ToolbarState' => 'Affichage par défaut de la barre d\'outil',
	'UI:Preferences:RichText:ToolbarState:Expanded' => 'Déplié',
	'UI:Preferences:RichText:ToolbarState:Collapsed' => 'Replié',
	'UI:Preferences:ActivityPanel:Title' => 'Panneau d\'activité',
	'UI:Preferences:ActivityPanel:EntryFormOpened' => 'Formulaire de saisie ouvert par défaut',
	'UI:Preferences:ActivityPanel:EntryFormOpened+' => 'État du formulaire de saisie lors de l\'affichage d\'un objet. Si la case est décochée, le formulaire pourra être ouvert en utilisant l\'icone "Nouvelle entrée".',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Title' => 'Raccourcis clavier de l\'application',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Input:Hint' => 'Saisissez un raccourci clavier',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Tooltip' => 'Enregistrer un raccourci clavier',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset' => 'Réinitialiser',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset:Tooltip' => 'Remettre les raccourcis claviers par défaut',
	'UI:Preferences:Tabs:Title' => 'Onglets',
	'UI:Preferences:Tabs:Layout:Label' => 'Affichage',
	'UI:Preferences:Tabs:Layout:Horizontal' => 'Horizontal',
	'UI:Preferences:Tabs:Layout:Vertical' => 'Vertical',
	'UI:Preferences:Tabs:Scrollable:Label' => 'Navigation',
	'UI:Preferences:Tabs:Scrollable:Classic' => 'Classique',
	'UI:Preferences:Tabs:Scrollable:Scrollable' => 'Défilement',
	'UI:Preferences:General:Toasts' => 'Position des notifications toast',
	'UI:Preferences:General:Toasts:Bottom' => 'En bas',
	'UI:Preferences:General:Toasts:Top' => 'En haut',
	'UI:Preferences:ChooseAPlaceholder' => 'Avatar de l\'utilisateur',
	'UI:Preferences:ChooseAPlaceholder+' => 'Choisissez un avatar qui sera affiché si le contact associé à votre compte utilisateur n\'en possède pas',
	'UI:Preferences:ChooseAPlaceholder:Success:Message' => 'Votre avatar a été mis à jour avec succès',
	'UI:Preferences:Notifications' => 'Notifications',
	'UI:Preferences:Notifications+' => 'Désabonnez-vous des notifications qui vous importunent (emails et news) en suivant <a href="%1$s">ce lien</a>.',
	
));
